Class: Stash::Wrapper::StashAdministrative

Inherits:
Object
  • Object
show all
Includes:
XML::Mapping
Defined in:
lib/stash/wrapper/stash_administrative.rb

Overview

Mapping for <st:stash_administrative>

Instance Method Summary collapse

Constructor Details

#initialize(version:, license:, embargo: nil, inventory: nil) ⇒ StashAdministrative

Parameters:

  • version (Version) —

    the version

  • license (License) —

    the license

  • embargo (Embargo, nil) (defaults to: nil) —

    the embargo information. If no Embargo is supplied, it will default to an embargo of type EmbargoType::NONE with the current date as start and end.

  • inventory (Inventory, nil) (defaults to: nil) —

    the (optional) file inventory



25
26
27
28
29
30
# File 'lib/stash/wrapper/stash_administrative.rb', line 25

def initialize(version:, license:, embargo: nil, inventory: nil)
  self.version = version
  self.license = license
  self.embargo = embargo || Embargo.none
  self.inventory = inventory
end